==> rdc_flutter_sdk-0.0.20-dev.tar.gz: lib/src/controllers/device_info_controller.dart <==
import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/material.dart';
import 'package:rdc_flutter_sdk/src/constants/app_constants.dart';
import 'package:rdc_flutter_sdk/src/util/advertising_helper.dart';
import 'package:realm/realm.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../util/device_helper.dart';

class DeviceInfoController {
  var osType = '';
  var osVersion = '';

  var globalId = '';

  var device = '';
  var model = '';
  var brandName = '';
  var board = '';
  var display = '';

  var maId = '';

  var isPhysicalDevice = false;

  Future<DeviceInfoController> init() async {
    await _getDeviceInfo();
    await getAdvertising();
    return this;
  }

  Future<void> _getDeviceInfo() async {
    try {
      var deviceInfoPlugin = DeviceInfoPlugin();
      var deviceInfo = await deviceInfoPlugin.deviceInfo;
      if (deviceInfo is AndroidDeviceInfo) {
        final sharedPreference = await SharedPreferences.getInstance();
        if (!sharedPreference.containsKey('rdc_globalId')) {
          globalId = Uuid.v4().toString();
          await sharedPreference.setString('rdc_globalId', globalId);
        } else {
          globalId = sharedPreference.getString('rdc_globalId')!;
        }

        osType = osTypeAndroid;
        osVersion = (deviceInfo.version.release).toString();
        device = deviceInfo.device;
        model = deviceInfo.model;
        brandName = deviceInfo.brand;
        board = deviceInfo.board;

        display = await DeviceHelper.getDisplay;
      } else if (deviceInfo is IosDeviceInfo) {
        globalId = deviceInfo.identifierForVendor ?? '';
        osType = osTypeIOS;
        osVersion = deviceInfo.systemVersion;
        device = deviceInfo.model;
        model = deviceInfo.localizedModel;
        brandName = 'Apple';

        isPhysicalDevice = deviceInfo.isPhysicalDevice;

        display =
            '${WidgetsBinding.instance.platformDispatcher.views.first.physicalSize.width.toInt()}x${WidgetsBinding.instance.platformDispatcher.views.first.physicalSize.height.toInt()}';
      }
    } catch (e) {
      //print(e.toString());
    }
  }

  Future<void> getAdvertising() async {
    try {
      maId = await AdvertisingHelper.getAdvertisingId();
    } catch (e) {
      //print(e.toString());
    }
  }
}

==> rdc_flutter_sdk_2-0.0.1-dev.1.tar.gz: lib/src/controllers/device_info_controller.dart <==
import 'package:device_info_plus/device_info_plus.dart';
import 'package:rdc_flutter_sdk_2/src/constants/app_constants.dart';
import 'package:rdc_flutter_sdk_2/src/util/advertising_helper.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';

import '../util/device_helper.dart';

class DeviceInfoController {
  var osType = '';
  var osVersion = '';

  var globalId = '';

  var device = '';
  var model = '';
  var brandName = '';
  var board = '';
  var display = '';

  var maId = '';

  var isPhysicalDevice = false;

  Future<DeviceInfoController> init() async {
    await _getDeviceInfo();
    await getAdvertising();
    return this;
  }

  Future<void> _getDeviceInfo() async {
    try {
      var deviceInfoPlugin = DeviceInfoPlugin();
      var deviceInfo = await deviceInfoPlugin.deviceInfo;
      if (deviceInfo is AndroidDeviceInfo) {
        final sharedPreference = await SharedPreferences.getInstance();
        if (!sharedPreference.containsKey('rdc_globalId')) {
          globalId = const Uuid().v4().toString();
          await sharedPreference.setString('rdc_globalId', globalId);
        } else {
          globalId = sharedPreference.getString('rdc_globalId')!;
        }

        osType = osTypeAndroid;
        osVersion = (deviceInfo.version.release ?? 0).toString();
        device = deviceInfo.device ?? '';
        model = deviceInfo.model ?? '';
        brandName = deviceInfo.brand ?? '';
        board = deviceInfo.board ?? '';
      } else if (deviceInfo is IosDeviceInfo) {
        globalId = deviceInfo.identifierForVendor ?? '';
        osType = osTypeIOS;
        osVersion = deviceInfo.systemVersion ?? '';
        device = deviceInfo.model ?? '';
        model = deviceInfo.localizedModel ?? '';
        brandName = 'Apple';

        isPhysicalDevice = deviceInfo.isPhysicalDevice;
      }

      display = await DeviceHelper.getDisplay;
    } catch (e) {
      //print(e.toString());
    }
  }

  Future<void> getAdvertising() async {
    try {
      maId = await AdvertisingHelper.getAdvertisingId();
    } catch (e) {
      //print(e.toString());
    }
  }
}
